@@ -738,7 +738,7 @@ static void up_session_mod(struct up_session *session, struct osmo_pfcp_msg *m)
 		return;
 	}
 
-	LOGPFSML(fi, LOGL_NOTICE, "Session modified: %s\n", up_session_gtp_status(session));
+	LOGPFSML(fi, LOGL_INFO, "Session modified: %s\n", up_session_gtp_status(session));
 	return;
 
 nack_response:
@@ -789,7 +789,7 @@ static void up_session_init_action(struct osmo_fsm_inst *fi, uint32_t event, voi
 static void up_session_established_onenter(struct osmo_fsm_inst *fi, uint32_t prev_state)
 {
 	struct up_session *session = fi->priv;
-	LOGPFSML(fi, LOGL_NOTICE, "Session established: %s %s\n", up_session_to_str_c(OTC_SELECT, session),
+	LOGPFSML(fi, LOGL_INFO, "Session established: %s %s\n", up_session_to_str_c(OTC_SELECT, session),
 		 up_session_gtp_status(session));
 }
 
@@ -820,7 +820,7 @@ static void up_session_established_onleave(struct osmo_fsm_inst *fi, uint32_t ne
 {
 	struct up_session *session = fi->priv;
 	struct up_gtp_action *a;
-	LOGPFSML(fi, LOGL_NOTICE, "Session releasing: %s %s\n", up_session_to_str_c(OTC_SELECT, session), up_session_gtp_status(session));
+	LOGPFSML(fi, LOGL_INFO, "Session releasing: %s %s\n", up_session_to_str_c(OTC_SELECT, session), up_session_gtp_status(session));
 
 	/* Shut down all active GTP rules */
 	while ((a = llist_first_entry_or_null(&session->active_gtp_actions, struct up_gtp_action, entry))) {
@@ -885,6 +885,7 @@ static void up_session_fsm_cleanup(struct osmo_fsm_inst *fi, enum osmo_fsm_term_
 
 	up_session_clear_pdr_far(session);
 
+	hash_del(&session->ep_node_by_up_seid);
 	hash_del(&session->node_by_up_seid);
 	hash_del(&session->node_by_cp_seid);
 }
@@ -1022,6 +1023,7 @@ static struct up_session *up_session_add(struct up_peer *peer, const struct osmo
 
 	hash_add(peer->sessions_by_up_seid, &session->node_by_up_seid, session->up_seid);
 	hash_add(peer->sessions_by_cp_seid, &session->node_by_cp_seid, session->cp_f_seid.seid);
+	hash_add(peer->up_endpoint->sessions_by_up_seid, &session->ep_node_by_up_seid, session->up_seid);
 	return session;
 }
 
